# drug-database
_________________

[![MIT](https://img.shields.io/github/license/ComputationalPhysiology/drug-database)](LICENSE)
[Read Latest Documentation](https://ComputationalPhysiology.github.io/drug-database/)
[![Test package](https://github.com/ComputationalPhysiology/drug-database/actions/workflows/main.yml/badge.svg)](https://github.com/ComputationalPhysiology/drug-database/actions/workflows/main.yml)
[![pre-commit](https://github.com/ComputationalPhysiology/drug-database/actions/workflows/pre-commit.yml/badge.svg)](https://github.com/ComputationalPhysiology/drug-database/actions/workflows/pre-commit.yml)
[![Deploy static content to Pages](https://github.com/ComputationalPhysiology/drug-database/actions/workflows/build_docs.yml/badge.svg)](https://github.com/ComputationalPhysiology/drug-database/actions/workflows/build_docs.yml)
_________________
